<?php
namespace App\Controller;

use Psr\Http\Message\ResponseInterface as Response;
use Psr\Http\Message\ServerRequestInterface as Request;

class Delay 
{
    private $delayService;

    public function __construct(\App\Service\Delay $delayService) 
    {
        $this->delayService = $delayService;
    }

    public function getStore(Request $request, Response $response) 
    {
        try {
            $params = $request->getQueryParams();
            
            $cdFilial = $this->delayService->getParamsValue($params, 'CDFILIALGRID');
            
            $result = $this->delayService->getStore($cdFilial);

            $response->getBody()->write(json_encode([
                'error' => false,
                'message' => '',
                'data' => $result,
                'pagination' => [
                    'limit' => $params['limit'] ?? 10,
                    'page' => $params['page'] ?? 1
                ],
            ]));

            return $response->withHeader('Content-Type', 'application/json');
        } catch (\Exception $e) {
            $response->getBody()->write(json_encode([
                'error'   => true,
                'message' => $e->getMessage(),
                'data'    => []
            ]));

            return $response->withHeader('Content-Type', 'application/json');
        }
    }

    public function filter(Request $request, Response $response) 
    {
        try {
            $params = $request->getParsedBody();
            $cdFilial = $this->delayService->getParamsValue($params, 'CDFILIALGRID');

            $result = $this->delayService->filter($cdFilial);
            $response->getBody()->write(json_encode([
                'error' => false,
                'message' => '',
                'data' => $result,
                'pagination' => [
                    'limit' => $params['limit'] ?? 10,
                    'page' => $params['page'] ?? 1
                ],
            ]));

            return $response->withHeader('Content-Type', 'application/json');
        } catch (\Exception $e) {
            $response->getBody()->write(json_encode([
                'error'   => true,
                'message' => $e->getMessage(),
                'data'    => []
            ]));

            return $response->withHeader('Content-Type', 'application/json');
        }
    }

    public function updateDelay(Request $request, Response $response) 
    {
        try {
            $params = $request->getParsedBody();

            $cdFilial = !empty($params['cdFilial']) ? $params['cdFilial'] : null;
            $cdLoja = !empty($params['cdLoja']) ? $params['cdLoja'] : null;
            $hrTempoAtraso = !empty($params['hrTempoAtraso']) && ($params['hrTempoAtraso'] == " - " || $params['hrTempoAtraso'] == 0) ? null : $params['hrTempoAtraso'];

            $paramsUpdate = [
                'cdFilial'      => $cdFilial,
                'cdLoja'        => $cdLoja,
                'hrTempoAtraso' => $hrTempoAtraso,
            ];

            $responseUpdate = $this->delayService->updateDelay($paramsUpdate);

            return $response->withHeader('Content-Type', 'application/json');
        } catch (\Exception $e) {
            $response->getBody()->write(json_encode([
                'error'   => true,
                'message' => $e->getMessage(),
                'data'    => []
            ]));

            return $response->withHeader('Content-Type', 'application/json');
        }
    }
}