import { ComponentRender } from '@zeedhi/common';
import { ITimer, ITimerEvents } from './interfaces';

type GridRow = {
  [key: string]: any;
};

type StylingType = {
  [key: string]: Array<number | null>
};

export class Timer extends ComponentRender implements ITimer {
  public startTime?: string;

  public currentTime?: string = '';

  public tooltipPropName?: string = '';

  public elapsedTimeSeconds?: number = 0;

  public row: GridRow = {};

  public styling?: StylingType;

  public freezeTimer?: boolean = false;

  public events!: ITimerEvents;

  constructor(props: ITimer) {
    super(props);
    this.startTime = this.getInitValue('startTime', props.startTime, this.startTime);
    this.tooltipPropName = this.getInitValue('tooltipPropName', props.tooltipPropName, this.tooltipPropName);
    this.styling = this.getInitValue('styling', props.styling, this.styling);
    this.row = this.getInitValue('row', props.row, this.row);
    this.createAccessors();
  }

  public setFixedTime(value: string) {
    this.freezeTimer = true;
    this.currentTime = value;
  }

  public startAnimationTime() {
    this.callEvent('onLoadTimer', { row: this.row, component: this });
  }

  public getRow() {
    return this.row;
  }

  public setRow(row: any) {
    this.row = row;
  }

  public getToolTip() {
    return ((this.row || {})[this.tooltipPropName || ''] || '').toString().concat('m');
  }
}
