import { alertService } from '@/helpers/AlertService';
import { Modal, ModalService } from '@zeedhi/common';
import { Http, Metadata } from '@zeedhi/core';
import { TekTreeGrid } from '@zeedhi/teknisa-components-common';
import { ZdTextInput } from '@zeedhi/vuetify';

export class EstimatedDelayController {
  private delayModal!: Modal;

  public getGrid(): TekTreeGrid {
    return Metadata.getInstance<TekTreeGrid>('estimated-delay-grid');
  }

  public async createDelayModal(): Promise<void> {
    this.delayModal = await ModalService.createFromJson('estimated-delay-modal', true);
  }

  public async openDelayModal(): Promise<void> {
    if (this.delayModal) this.delayModal.destroy();
    this.delayModal = await ModalService.createFromJson('estimated-delay-modal', true);

    this.delayModal.show();
  }

  public closeDelayModal(): void {
    this.delayModal.destroy();
  }

  public async openDelayModalWithData({ row }: any): Promise<void> {
    if (row && row.CDLOJA) {
      try {
        if (this.delayModal) {
          this.delayModal.destroy();
        }

        this.delayModal = await ModalService.createFromJson('estimated-delay-modal', true);
        await this.delayModal.show();

        const {
          CDFILIAL, CDLOJA, HRTEMPOATRASO, NMLOJA,
        } = row;

        const textCdFilial = Metadata.getInstance<ZdTextInput>('CDFILIAL');
        textCdFilial.value = CDFILIAL;

        const textCdLoja = Metadata.getInstance<ZdTextInput>('CDLOJA');
        textCdLoja.value = CDLOJA;

        const textDelay = Metadata.getInstance<ZdTextInput>('HRTEMPOATRASO');
        textDelay.value = HRTEMPOATRASO;

        const textNMLOJA = Metadata.getInstance<ZdTextInput>('NMLOJA');
        textNMLOJA.value = NMLOJA;
      } catch (error) {
        if (error instanceof Error) {
          alertService('error', error.message, 'red');
        }
      }
    }
  }

  public async updateDelay(): Promise<void> {
    try {
      const cdFilial = Metadata.getInstance<ZdTextInput>('CDFILIAL');
      const cdLoja = Metadata.getInstance<ZdTextInput>('CDLOJA');
      const hrTempoAtraso = Metadata.getInstance<ZdTextInput>('HRTEMPOATRASO');

      const data = {
        cdFilial: cdFilial.value,
        cdLoja: cdLoja.value,
        hrTempoAtraso: hrTempoAtraso.value,
      };

      await Http.post('/delay/updateDelay', data);

      this.getGrid().datasource.get();
      this.closeDelayModal();
    } catch (error) {
      if (error instanceof Error) {
        alertService('error', error.message, 'red');
      }
    }
  }

  public clearTextField(): void {
    const HRTEMPOATRASO = Metadata.getInstance<ZdTextInput>('HRTEMPOATRASO');
    if (HRTEMPOATRASO) {
      HRTEMPOATRASO.value = '';
    }
  }
}
